ProblemDetail

Struct ProblemDetail 

pub struct ProblemDetail {
    pub error_type: String,
    pub title: String,
    pub status: u16,
    pub detail: String,
    pub instance: Option<String>,
    pub code: ErrorCode,
    pub retryable: bool,
    pub details: HashMap<String, Value>,
}
RFC 9457 Problem Details — the single canonical error response envelope for transport error responses in rskit.

Serialises to:

{
  "type": "https://rskit.dev/errors/not-found",
  "title": "Not Found",
  "status": 404,
  "detail": "user '42' not found",
  "code": "NOT_FOUND",
  "retryable": false
}

Fields

error_type: String

URI reference that identifies the problem type (RFC 9457 3.1.1).

title: String

Short, human-readable summary of the problem type (RFC 9457 3.1.2).

status: u16

HTTP status code (RFC 9457 3.1.3).

detail: String

Human-readable explanation specific to this occurrence (RFC 9457 3.1.4).

instance: Option<String>

URI reference identifying this specific occurrence (RFC 9457 3.1.5).

code: ErrorCode

Machine-readable error code (rskit extension).

retryable: bool

Whether the operation that produced this error is safe to retry (rskit extension).

details: HashMap<String, Value>

Arbitrary key-value pairs providing additional context (rskit extension).